==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A partilha entre servidores não se encontra disponível neste servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém carateres inválidos.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar para a partilha remota, a palavra-passe poderá estar errada",
    "Storage not valid" : "Armazenamento inválido",
    "Couldn't add remote share" : "Não foi possível adicionar a partilha remota",
    "Shared with you" : "Partilhado consigo ",
    "Shared with others" : "Partilhado com outros",
    "Shared by link" : "Partilhado pela hiperligação",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que os outros partilham consigo, serão mostradaos aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar a partilha remota {nome} de {proprietário}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Senha da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Não foi encontrada nenhuma instalação OwnCloud (7 ou superior) em {remote}",
    "Invalid ownCloud url" : "Url ownCloud inválido",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi  <strong>transferido</strong> um ficheiro ou pasta partilhada publicamente",
    "You received a new remote share %2$s from %1$s" : "Recebeu uma nova partilha remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recebeu uma nova partilha remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou a partilha remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s rejeitou a partilha remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s cancelou a partilha %2$s consigo",
    "Public shared folder %1$s was downloaded" : "A pasta partilhada publicamente %1$s foi transferida",
    "Public shared file %1$s was downloaded" : "Foi transferido o ficheiro %1$s partilhado publicamente",
    "You shared %1$s with %2$s" : "Partilhou %1$s com %2$s",
    "You shared %1$s with group %2$s" : "Partilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with you" : "%2$s partilhou %1$s consigo",
    "You shared %1$s via link" : "Partilhou %1$s através de uma hiperligação",
    "Shares" : "Partilhas",
    "Accept" : "Aceitar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partilhe comigo através da minha Id. da Nuvem Federada #ownCloud, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #ownCloud",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "The password is wrong. Try again." : "A senha está errada. Por favor, tente de novo.",
    "Password" : "Senha",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "A hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Add to your ownCloud" : "Adicionar à sua ownCloud",
    "Download" : "Transferir",
    "Download %s" : "Transferir %s",
    "Direct link" : "Hiperligação direta",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir utilizadores neste servidor para enviar as partilhas para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir utilizadores neste servidor para receber as partilhas de outros servidores",
    "Federated Cloud" : "Nuvem Federada",
    "Your Federated Cloud ID:" : "A Sua Id. da Nuvem Federada",
    "Share it:" : "Partilhe:",
    "Add to your website" : "Adicione ao seu sítio da Web",
    "Share with me via ownCloud" : "Partilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A partilha entre servidores não se encontra disponível neste servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém carateres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não é possível criar uma partilha federada com o mesmo servidor de utilizador",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar para a partilha remota, a palavra-passe poderá estar errada",
    "Storage not valid" : "Armazenamento inválido",
    "Couldn't add remote share" : "Não foi possível adicionar a partilha remota",
    "Shared with you" : "Partilhado consigo ",
    "Shared with others" : "Partilhado com outros",
    "Shared by link" : "Partilhado pela hiperligação",
    "Federated sharing" : "Partilha federada",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que os outros partilham consigo, serão mostradaos aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar a partilha remota {nome} de {proprietário}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Senha da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Não foi encontrada nenhuma instalação OwnCloud (7 ou superior) em {remote}",
    "Invalid ownCloud url" : "Url ownCloud inválido",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi  <strong>transferido</strong> um ficheiro ou pasta partilhada publicamente",
    "You received a new remote share %2$s from %1$s" : "Recebeu uma nova partilha remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recebeu uma nova partilha remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou a partilha remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s rejeitou a partilha remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s cancelou a partilha %2$s consigo",
    "Public shared folder %1$s was downloaded" : "A pasta partilhada publicamente %1$s foi transferida",
    "Public shared file %1$s was downloaded" : "Foi transferido o ficheiro %1$s partilhado publicamente",
    "You shared %1$s with %2$s" : "Partilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s partilhou %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Removeu a partilha de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removeu a partilha de %3$s para %1$s",
    "You shared %1$s with group %2$s" : "Partilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partilhou %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Removeu a partilha do grupo %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removeu a partilha do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s partilhou %1$s via hiperligação",
    "You shared %1$s via link" : "Partilhou %1$s através de uma hiperligação",
    "You removed the public link for %1$s" : "Removeu o link público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu o link público de %1$s",
    "Your public link for %1$s expired" : "O seu link público de %1$s expirou",
    "The public link of %2$s for %1$s expired" : "O link público de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s partilhou %1$s consigo",
    "%2$s removed the share for %1$s" : "%2$s removeu a partilha para %1$s",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Shared with %2$s" : "Partilhado com %2$s",
    "Shared with %3$s by %2$s" : "Partilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Partilha removida para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu a partilha para %3$s",
    "Shared with group %2$s" : "Partilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Partilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Partilha removida do grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removeu a partilha do grupo %3$s",
    "Shared via link by %2$s" : "Partilhado via hiperligação por %2$s",
    "Shared via public link" : "Partilhado via hiperligação pública",
    "Removed public link" : "Removeu link público",
    "%2$s removed public link" : "%2$s removeu link público",
    "Public link expired" : "Link público expirou",
    "Public link of %2$s expired" : "Link público de %2$s expirou",
    "Shared by %2$s" : "Partilhado por %2$s",
    "Shares" : "Partilhas",
    "You received \"/%2$s\" as a remote share from %1$s" : "Recebeu \"/%2$s\" como uma partilha remota de %1$s",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partilhe comigo através da minha Id. da Nuvem Federada #ownCloud, veja %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #ownCloud",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "The password is wrong. Try again." : "A senha está errada. Por favor, tente de novo.",
    "Password" : "Senha",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "A hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Add to your ownCloud" : "Adicionar à sua ownCloud",
    "Download" : "Transferir",
    "Download %s" : "Transferir %s",
    "Direct link" : "Hiperligação direta",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Allow users on this server to send shares to other servers" : "Permitir utilizadores neste servidor para enviar as partilhas para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir utilizadores neste servidor para receber as partilhas de outros servidores",
    "Federated Cloud" : "Nuvem Federada",
    "Your Federated Cloud ID:" : "A Sua Id. da Nuvem Federada",
    "Share it:" : "Partilhe:",
    "Add to your website" : "Adicione ao seu sítio da Web",
    "Share with me via ownCloud" : "Partilhe comigo via ownCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n != 1);");
